@@ -15,6 +15,8 @@ import sys
 from datetime import datetime
 from typing import IO, Any, Dict, List, Union
 
+from botocore.response import StreamingBody
+
 from .literals import (
     ChannelStatusType,
     ComputeTypeType,
@@ -70,6 +72,8 @@ __all__ = (
     "DatasetTriggerTypeDef",
     "DatasetTypeDef",
     "DatastoreActivityTypeDef",
+    "DatastorePartitionTypeDef",
+    "DatastorePartitionsTypeDef",
     "DatastoreStatisticsTypeDef",
     "DatastoreStorageSummaryTypeDef",
     "DatastoreStorageTypeDef",
@@ -105,6 +109,7 @@ __all__ = (
     "OutputFileUriValueTypeDef",
     "PaginatorConfigTypeDef",
     "ParquetConfigurationTypeDef",
+    "PartitionTypeDef",
     "PipelineActivityTypeDef",
     "PipelineSummaryTypeDef",
     "PipelineTypeDef",
@@ -122,6 +127,7 @@ __all__ = (
     "SqlQueryDatasetActionTypeDef",
     "StartPipelineReprocessingResponseTypeDef",
     "TagTypeDef",
+    "TimestampPartitionTypeDef",
     "TriggeringDatasetTypeDef",
     "VariableTypeDef",
     "VersioningConfigurationTypeDef",
@@ -526,6 +532,23 @@ DatastoreActivityTypeDef = TypedDict(
     },
 )
 
+DatastorePartitionTypeDef = TypedDict(
+    "DatastorePartitionTypeDef",
+    {
+        "attributePartition": "PartitionTypeDef",
+        "timestampPartition": "TimestampPartitionTypeDef",
+    },
+    total=False,
+)
+
+DatastorePartitionsTypeDef = TypedDict(
+    "DatastorePartitionsTypeDef",
+    {
+        "partitions": List["DatastorePartitionTypeDef"],
+    },
+    total=False,
+)
+
 DatastoreStatisticsTypeDef = TypedDict(
     "DatastoreStatisticsTypeDef",
     {
@@ -562,6 +585,7 @@ DatastoreSummaryTypeDef = TypedDict(
         "lastUpdateTime": datetime,
         "lastMessageArrivalTime": datetime,
         "fileFormatType": FileFormatTypeType,
+        "datastorePartitions": "DatastorePartitionsTypeDef",
     },
     total=False,
 )
@@ -578,6 +602,7 @@ DatastoreTypeDef = TypedDict(
         "lastUpdateTime": datetime,
         "lastMessageArrivalTime": datetime,
         "fileFormatConfiguration": "FileFormatConfigurationTypeDef",
+        "datastorePartitions": "DatastorePartitionsTypeDef",
     },
     total=False,
 )
@@ -886,7 +911,7 @@ MessageTypeDef = TypedDict(
     "MessageTypeDef",
     {
         "messageId": str,
-        "payload": Union[bytes, IO[bytes]],
+        "payload": Union[bytes, IO[bytes], StreamingBody],
     },
 )
 
@@ -915,6 +940,13 @@ ParquetConfigurationTypeDef = TypedDict(
     total=False,
 )
 
+PartitionTypeDef = TypedDict(
+    "PartitionTypeDef",
+    {
+        "attributeName": str,
+    },
+)
+
 PipelineActivityTypeDef = TypedDict(
     "PipelineActivityTypeDef",
     {
@@ -1016,7 +1048,7 @@ RetentionPeriodTypeDef = TypedDict(
 RunPipelineActivityResponseTypeDef = TypedDict(
     "RunPipelineActivityResponseTypeDef",
     {
-        "payloads": List[Union[bytes, IO[bytes]]],
+        "payloads": List[Union[bytes, IO[bytes], StreamingBody]],
         "logResult": str,
     },
     total=False,
@@ -1048,7 +1080,7 @@ class S3DestinationConfigurationTypeDef(
 SampleChannelDataResponseTypeDef = TypedDict(
     "SampleChannelDataResponseTypeDef",
     {
-        "payloads": List[Union[bytes, IO[bytes]]],
+        "payloads": List[Union[bytes, IO[bytes], StreamingBody]],
     },
     total=False,
 )
@@ -1128,6 +1160,27 @@ TagTypeDef = TypedDict(
     },
 )
 
+_RequiredTimestampPartitionTypeDef = TypedDict(
+    "_RequiredTimestampPartitionTypeDef",
+    {
+        "attributeName": str,
+    },
+)
+_OptionalTimestampPartitionTypeDef = TypedDict(
+    "_OptionalTimestampPartitionTypeDef",
+    {
+        "timestampFormat": str,
+    },
+    total=False,
+)
+
+
+class TimestampPartitionTypeDef(
+    _RequiredTimestampPartitionTypeDef, _OptionalTimestampPartitionTypeDef
+):
+    pass
+
+
 TriggeringDatasetTypeDef = TypedDict(
     "TriggeringDatasetTypeDef",
     {
